@@ -1,4 +1,4 @@
-/* $Id: xfburn-blank-dialog.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-blank-dialog.c 6048 2008-11-10 05:36:10Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -29,6 +29,7 @@
 #include "xfburn-utils.h"
 #include "xfburn-progress-dialog.h"
 #include "xfburn-device-box.h"
+#include "xfburn-device-list.h"
 #include "xfburn-stock.h"
 #include "xfburn-hal-manager.h"
 #include "xfburn-main.h"
@@ -125,6 +126,7 @@ xfburn_blank_dialog_get_type ()
       sizeof (XfburnBlankDialog),
       0,
       (GInstanceInitFunc) xfburn_blank_dialog_init,
+      NULL,
     };
 
     type = g_type_register_static (XFCE_TYPE_TITLED_DIALOG, "XfburnBlankDialog", &our_info, 0);
@@ -193,7 +195,7 @@ xfburn_blank_dialog_init (XfburnBlankDialog * obj)
   GtkListStore *store = NULL;
   GtkCellRenderer *cell;
   
-  gtk_window_set_title (GTK_WINDOW (obj), _("Blank CD-RW"));
+  gtk_window_set_title (GTK_WINDOW (obj), _("Blank Disc"));
   gtk_window_set_destroy_with_parent (GTK_WINDOW (obj), TRUE);
   
   icon = gtk_widget_render_icon (GTK_WIDGET (obj), XFBURN_STOCK_BLANK_CDRW, GTK_ICON_SIZE_DIALOG, NULL);
@@ -346,7 +348,7 @@ thread_blank_perform_blank (ThreadBlankParams * params, struct burn_drive_info *
   case BURN_DISC_BLANK:
     if (params->blank_mode == XFBURN_BLANK_FAST || params->blank_mode == XFBURN_BLANK_COMPLETE) {
       /* blanking can only be performed on blank discs, format and deformat are allowed to be blank ones */
-      xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("The inserted disc is already blank"));
+      xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("The inserted disc is already blank."));
       return FALSE;
     }
   case BURN_DISC_FULL:
@@ -355,16 +357,16 @@ thread_blank_perform_blank (ThreadBlankParams * params, struct burn_drive_info *
     xfburn_progress_dialog_set_status_with_text (XFBURN_PROGRESS_DIALOG (dialog_progress), XFBURN_PROGRESS_DIALOG_STATUS_RUNNING, _("Ready"));
     break;
   case BURN_DISC_EMPTY:
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("No disc detected in the drive"));
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("No disc detected in the drive."));
     return FALSE;
   default:
-    //xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Cannot recognize drive and media state"));
+    //xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Cannot recognize drive and disc state."));
     //return FALSE;
     break;
   }
 
   if (!burn_disc_erasable (drive)) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Media is not erasable"));
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Disc is not erasable."));
     return FALSE;
   }
 
@@ -442,13 +444,6 @@ thread_blank_perform_blank (ThreadBlankParams * params, struct burn_drive_info *
   xfburn_progress_dialog_set_status_with_text (XFBURN_PROGRESS_DIALOG (dialog_progress), final_status, final_message);
   g_free (final_message);
 
-#ifdef HAVE_HAL
-  gdk_threads_enter ();
-  DBG ("blanking done!");
-  xfburn_hal_manager_send_volume_changed ();
-  gdk_threads_leave ();
-#endif 
-
   return TRUE;
 }
 
@@ -457,25 +452,21 @@ thread_blank (ThreadBlankParams * params)
 {
   struct burn_drive_info *drive_info = NULL;
 
-  if (!burn_initialize ()) {
-    g_critical ("Unable to initialize libburn");
-    g_free (params);
-    return;
-  }
-
   if (!xfburn_device_grab (params->device, &drive_info)) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (params->dialog_progress), _("Unable to grab drive"));
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (params->dialog_progress), _("Unable to grab the drive."));
   } else {
     thread_blank_perform_blank (params, drive_info);
-    burn_drive_release (drive_info->drive, params->eject ? 1 : 0);
+    xfburn_device_release (drive_info, params->eject);
   }
  
-  burn_finish ();
   g_free (params);
 
+#ifdef HAVE_HAL
   gdk_threads_enter ();
+  DBG ("blanking done!");
   xfburn_hal_manager_send_volume_changed ();
   gdk_threads_leave ();
+#endif
 }
 
 static XfburnBlankMode
