@@ -1,4 +1,4 @@
-/* $Id: xfburn-compositions-notebook.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-compositions-notebook.c 5931 2008-11-03 06:14:41Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -30,13 +30,14 @@
 #include "xfburn-notebook-tab.h"
 #include "xfburn-welcome-tab.h"
 #include "xfburn-data-composition.h"
+#include "xfburn-audio-composition.h"
 
 #define XFBURN_COMPOSITIONS_NOTEBOOK_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_COMPOSITIONS_NOTEBOOK, XfburnCompositionsNotebookPrivate))
 
 /* private members */
 typedef struct
 {
-  gpointer gna;
+  gpointer dummy;
 } XfburnCompositionsNotebookPrivate;
 
 
@@ -73,6 +74,7 @@ xfburn_compositions_notebook_get_type ()
       sizeof (XfburnCompositionsNotebook),
       0,
       (GInstanceInitFunc) xfburn_compositions_notebook_init,
+      NULL
     };
 
     type = g_type_register_static (GTK_TYPE_NOTEBOOK, "XfburnCompositionsNotebook", &our_info, 0);
@@ -137,6 +139,8 @@ cb_composition_close (XfburnNotebookTab *tab, GtkNotebook *notebook)
   composition = g_object_get_data (G_OBJECT (tab), "composition");
   page_num = gtk_notebook_page_num (notebook, composition);
   gtk_notebook_remove_page (notebook, page_num);
+
+  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook)) > 1);
 }
 
 static void
@@ -160,17 +164,14 @@ add_composition_with_data (XfburnCompositionsNotebook *notebook, XfburnCompositi
   gchar *label_text = NULL;
   static guint i = 0;
   
-  switch (type) {
-    case XFBURN_WELCOME_TAB:
-      composition = xfburn_welcome_tab_new (window, notebook);
-      label_text = g_strdup (_("Welcome"));
-      break;
+  switch (type) {   
     case XFBURN_DATA_COMPOSITION:
       composition = xfburn_data_composition_new ();
       label_text = g_strdup_printf ("%s %d", _("Data composition"), ++i);
       break;
     case XFBURN_AUDIO_COMPOSITION:
-      DBG ("don't hurry ... it'll be implemented later");
+      composition = xfburn_audio_composition_new ();
+      label_text = g_strdup_printf ("%s %d", _("Audio composition"), ++i);
       break;
   }
   
@@ -180,7 +181,7 @@ add_composition_with_data (XfburnCompositionsNotebook *notebook, XfburnCompositi
     
     guint page_num;
     
-    tab = xfburn_notebook_tab_new (label_text);
+    tab = xfburn_notebook_tab_new (label_text, TRUE);
     gtk_widget_show (tab);
 	
     menu_label = gtk_label_new (label_text);
@@ -192,9 +193,10 @@ add_composition_with_data (XfburnCompositionsNotebook *notebook, XfburnCompositi
 
     gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK (notebook), composition, 1);
 	
+    gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook)) > 1);
+
     g_object_set_data (G_OBJECT (tab), "composition", composition);
-    if (type != XFBURN_WELCOME_TAB)
-      g_signal_connect (G_OBJECT (tab), "button-close-clicked", G_CALLBACK (cb_composition_close), notebook);
+    g_signal_connect (G_OBJECT (tab), "button-close-clicked", G_CALLBACK (cb_composition_close), notebook);
     
     g_signal_connect (G_OBJECT (composition), "name-changed", G_CALLBACK (cb_composition_name_changed), notebook);
   }
@@ -220,15 +222,22 @@ xfburn_compositions_notebook_new ()
 XfburnComposition *
 xfburn_compositions_notebook_add_composition (XfburnCompositionsNotebook *notebook, XfburnCompositionType type)
 {
-  g_assert (type != XFBURN_WELCOME_TAB);
-
   return add_composition_with_data (notebook, type, NULL);
 }
 
-XfburnWelcomeTab *
-xfburn_compositions_notebook_add_welcome_tab (XfburnCompositionsNotebook *notebook, XfburnMainWindow *window)
+void
+xfburn_compositions_notebook_add_welcome_tab (XfburnCompositionsNotebook *notebook, GtkActionGroup *action_group)
 {
-  return XFBURN_WELCOME_TAB (add_composition_with_data (notebook, XFBURN_WELCOME_TAB, window));
+  GtkWidget *welcome_tab = NULL;
+  GtkWidget *label;
+
+  welcome_tab = xfburn_welcome_tab_new (notebook, action_group);
+  label = gtk_label_new (_("Welcome"));
+
+  gtk_widget_show (welcome_tab);
+  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), welcome_tab, label);
+
+  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook)) > 1);
 }
 
 void
@@ -237,7 +246,9 @@ xfburn_compositions_notebook_close_composition (XfburnCompositionsNotebook *note
   gint page_num;
   
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
-  gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), page_num);
+  if (page_num > 0)
+    /* don't close the welcome page */
+    gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), page_num);
 }
 
 void
