@@ -1,4 +1,4 @@
-/* $Id: xfburn-data-composition.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-data-composition.c 6780 2009-02-25 07:07:53Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -44,6 +44,7 @@
 #include <exo/exo.h>
 
 #include <libisofs.h>
+#include <glib/gstdio.h>
 
 #include "xfburn-data-composition.h"
 #include "xfburn-global.h"
@@ -123,8 +124,8 @@ static void cb_selection_changed (GtkTreeSelection *selection, XfburnDataComposi
 static void cb_begin_burn (XfburnDataDiscUsage * du, XfburnDataComposition * dc);
 static void cb_cell_file_edited (GtkCellRenderer * renderer, gchar * path, gchar * newtext, XfburnDataComposition * dc);
 
-static void cb_content_drag_data_rcv (GtkWidget *, GdkDragContext *, guint, guint, GtkSelectionData *, guint, guint,
-                                      XfburnDataComposition *);
+static void cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guint y, GtkSelectionData * sd,
+                                      guint info, guint t, XfburnDataComposition * composition);
 static void cb_content_drag_data_get (GtkWidget * widget, GdkDragContext * dc, GtkSelectionData * data, guint info,
                                       guint time, XfburnDataComposition * content);
 static void cb_adding_done (XfburnAddingProgress *progress, XfburnDataComposition *dc);
@@ -149,7 +150,7 @@ typedef struct
  
   guint n_new_directory;
 
-  GSList *full_paths_to_add;
+  GList *full_paths_to_add;
   gchar *selected_files;
   GtkTreePath *path_where_insert;
 
@@ -184,7 +185,7 @@ static const GtkActionEntry action_entries[] = {
    G_CALLBACK (action_remove_selection),},
   {"clear", GTK_STOCK_CLEAR, N_("Clear"), NULL, N_("Clear the content of the composition"),
    G_CALLBACK (action_clear),},
-  {"import-session", "xfburn-import-session", N_("Import"), NULL, N_("Import existing session"),},
+  /*{"import-session", "xfburn-import-session", N_("Import"), NULL, N_("Import existing session"),}, */
   {"rename-file", GTK_STOCK_EDIT, N_("Rename"), NULL, N_("Rename the selected file"),
    G_CALLBACK (action_rename_selection),},
 };
@@ -217,7 +218,8 @@ xfburn_data_composition_get_type (void)
       NULL,
       sizeof (XfburnDataComposition),
       0,
-      (GInstanceInitFunc) xfburn_data_composition_init
+      (GInstanceInitFunc) xfburn_data_composition_init,
+      NULL
     };
 
     static const GInterfaceInfo composition_info = {
@@ -278,10 +280,13 @@ xfburn_data_composition_init (XfburnDataComposition * composition)
     "<menuitem action=\"create-dir\"/>" "<separator/>"
     "<menuitem action=\"rename-file\"/>" "<menuitem action=\"remove-file\"/>" "</popup></ui>";
 
-  GtkTargetEntry gte_src[] = { {"XFBURN_TREE_PATHS", GTK_TARGET_SAME_WIDGET, DATA_COMPOSITION_DND_TARGET_INSIDE} };
-  GtkTargetEntry gte_dest[] = { {"XFBURN_TREE_PATHS", GTK_TARGET_SAME_WIDGET, DATA_COMPOSITION_DND_TARGET_INSIDE},
-  {"text/plain", 0, DATA_COMPOSITION_DND_TARGET_TEXT_PLAIN}
-  };
+  GtkTargetEntry gte_src[] =  { { "XFBURN_TREE_PATHS", GTK_TARGET_SAME_WIDGET, DATA_COMPOSITION_DND_TARGET_INSIDE } };
+  GtkTargetEntry gte_dest[] = { { "XFBURN_TREE_PATHS", GTK_TARGET_SAME_WIDGET, DATA_COMPOSITION_DND_TARGET_INSIDE },
+                                { "text/plain", 0, DATA_COMPOSITION_DND_TARGET_TEXT_PLAIN },
+#ifdef HAVE_THUNAR_VFS
+                                { "text/uri-list", 0, DATA_COMPOSITION_DND_TARGET_TEXT_URI_LIST },
+#endif
+                              };
 
   priv->full_paths_to_add = NULL;
 
@@ -482,7 +487,7 @@ cb_begin_burn (XfburnDataDiscUsage * du, XfburnDataComposition * dc)
 
   image = generate_iso_image (XFBURN_DATA_COMPOSITION (dc));
   
-  switch (xfburn_data_disc_usage_get_disc_type (du)) {
+  switch (xfburn_disc_usage_get_disc_type (XFBURN_DISC_USAGE (du))) {
   case CD_DISC:
     dialog = xfburn_burn_data_cd_composition_dialog_new (image);
     break;
@@ -659,7 +664,7 @@ cb_cell_file_edited (GtkCellRenderer * renderer, gchar * path, gchar * newtext,
   GtkTreePath *real_path;
 
   if (strlen (newtext) == 0) {
-    xfce_err (_("You must give a name to the file"));
+    xfce_err (_("You must give a name to the file."));
     return;
   }
     
@@ -668,7 +673,7 @@ cb_cell_file_edited (GtkCellRenderer * renderer, gchar * path, gchar * newtext,
 
   if (gtk_tree_model_get_iter (model, &iter, real_path)) {
     if (file_exists_on_same_level (model, real_path, TRUE, newtext)) {
-      xfce_err (_("A file with the same name is already present in the composition"));
+      xfce_err (_("A file with the same name is already present in the composition."));
     }
     else {
       gtk_tree_store_set (GTK_TREE_STORE (model), &iter, DATA_COMPOSITION_COLUMN_CONTENT, newtext, -1);
@@ -696,8 +701,8 @@ cb_adding_done (XfburnAddingProgress *progress, XfburnDataComposition *dc)
   }
 
   if (priv->full_paths_to_add) {
-    g_slist_foreach (priv->full_paths_to_add, (GFunc) g_free, NULL);
-    g_slist_free (priv->full_paths_to_add);
+    g_list_foreach (priv->full_paths_to_add, (GFunc) g_free, NULL);
+    g_list_free (priv->full_paths_to_add);
     priv->full_paths_to_add = NULL;
   }
 
@@ -791,7 +796,7 @@ action_create_directory (GtkAction * action, XfburnDataComposition * dc)
   g_free (directory_text);
   g_free (humansize);
   
-  xfburn_data_disc_usage_add_size (XFBURN_DATA_DISC_USAGE (priv->disc_usage), 4);
+  xfburn_disc_usage_add_size (XFBURN_DISC_USAGE (priv->disc_usage), 4);
   
   gtk_widget_realize (priv->content);
   
@@ -821,7 +826,7 @@ remove_row_reference (GtkTreeRowReference *reference, XfburnDataCompositionPriva
       guint64 size = 0;
       
       gtk_tree_model_get (model, &iter, DATA_COMPOSITION_COLUMN_SIZE, &size, -1);
-      xfburn_data_disc_usage_sub_size (XFBURN_DATA_DISC_USAGE (priv->disc_usage), size);
+      xfburn_disc_usage_sub_size (XFBURN_DISC_USAGE (priv->disc_usage), size);
 
       iter_temp = iter;
       while (gtk_tree_model_iter_parent (model, &parent, &iter_temp)) {
@@ -940,7 +945,7 @@ action_clear (GtkAction * action, XfburnDataComposition * dc)
   
   gtk_entry_set_text (GTK_ENTRY (priv->entry_volume_name), _(DATA_COMPOSITION_DEFAULT_NAME));
 
-  xfburn_data_disc_usage_set_size (XFBURN_DATA_DISC_USAGE (priv->disc_usage), 0);
+  xfburn_disc_usage_set_size (XFBURN_DISC_USAGE (priv->disc_usage), 0);
 }
 
 static void
@@ -1007,25 +1012,25 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnDataComposition * dc
   
   struct stat s;
 
-  if ((stat (path, &s) == 0)) {
-    gchar *basename = NULL;
+  if ((g_lstat (path, &s) == 0)) {
+    //gchar *basename = NULL;
     gchar *humansize = NULL;
     GtkTreeIter *parent = NULL;
     GtkTreePath *tree_path = NULL;
 
-    if (!S_ISDIR (s.st_mode) && !S_ISREG (s.st_mode)) {
+    if (!(S_ISDIR (s.st_mode) ||S_ISREG (s.st_mode) || S_ISCHR(s.st_mode) || S_ISBLK(s.st_mode) || S_ISLNK (s.st_mode))) {
       return FALSE;
     }
     
+    /* allow hidden files
     basename = g_path_get_basename (path);
     if ( (strlen (basename) > 1) && (basename[0] == '.') ) {
-      /* FIXME: is this really what we want? */
-      /* don't add hidden files/directories */
 
       g_free (basename);  
       return FALSE;
     }
     g_free (basename);
+    */
     
     xfburn_adding_progress_pulse (XFBURN_ADDING_PROGRESS (priv->progress));
     
@@ -1063,7 +1068,7 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnDataComposition * dc
     
     gdk_threads_enter ();
     if (file_exists_on_same_level (model, tree_path, FALSE, name)) {
-      xfce_err (_("A file with the same name is already present in the composition"));
+      xfce_err (_("A file with the same name is already present in the composition."));
 
       gtk_tree_path_free (tree_path);
       gdk_threads_leave ();
@@ -1074,7 +1079,7 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnDataComposition * dc
     gdk_threads_leave ();
     
     /* new directory */
-    if (S_ISDIR (s.st_mode)) {
+    if (S_ISDIR (s.st_mode) && !S_ISLNK (s.st_mode)) {
       GDir *dir = NULL;
       GError *error = NULL;
       const gchar *filename = NULL;
@@ -1097,8 +1102,9 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnDataComposition * dc
                           DATA_COMPOSITION_COLUMN_ICON, icon_directory,
                           DATA_COMPOSITION_COLUMN_CONTENT, name,
                           DATA_COMPOSITION_COLUMN_TYPE, DATA_COMPOSITION_TYPE_DIRECTORY, 
+                          DATA_COMPOSITION_COLUMN_PATH, path,
                           DATA_COMPOSITION_COLUMN_SIZE, (guint64) 4, -1);
-      xfburn_data_disc_usage_add_size (XFBURN_DATA_DISC_USAGE (priv->disc_usage), (guint64) 4);
+      xfburn_disc_usage_add_size (XFBURN_DISC_USAGE (priv->disc_usage), (guint64) 4);
       gdk_threads_leave ();
 
       while ((filename = g_dir_read_name (dir))) {
@@ -1129,7 +1135,7 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnDataComposition * dc
       g_dir_close (dir);
     }
     /* new file */
-    else if (S_ISREG (s.st_mode)) {
+    else if (S_ISREG (s.st_mode) || S_ISCHR(s.st_mode) || S_ISBLK(s.st_mode) || S_ISLNK (s.st_mode)) {
 #ifdef HAVE_THUNAR_VFS
       GdkScreen *screen;
       GtkIconTheme *icon_theme;
@@ -1138,6 +1144,14 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnDataComposition * dc
       const gchar *mime_icon_name = NULL;
       GdkPixbuf *mime_icon = NULL;
       gint x,y;
+
+      if (s.st_size > MAXIMUM_ISO_FILE_SIZE) {
+        gdk_threads_enter ();
+        xfce_err (_("%s cannot be added to the composition, because it exceeds the maximum allowed file size for iso9660."), path);
+        gdk_threads_leave ();
+
+        return FALSE;
+      }
 	  
       gdk_threads_enter ();
       screen = gtk_widget_get_screen (GTK_WIDGET (dc));
@@ -1160,18 +1174,20 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnDataComposition * dc
                           DATA_COMPOSITION_COLUMN_ICON, (G_IS_OBJECT (mime_icon) ? mime_icon : icon_file),
                           DATA_COMPOSITION_COLUMN_CONTENT, name,
                           DATA_COMPOSITION_COLUMN_HUMANSIZE, humansize,
-                          DATA_COMPOSITION_COLUMN_SIZE, (guint64) s.st_size, DATA_COMPOSITION_COLUMN_PATH, path,
+                          DATA_COMPOSITION_COLUMN_SIZE, (guint64) s.st_size, 
+                          DATA_COMPOSITION_COLUMN_PATH, path,
                           DATA_COMPOSITION_COLUMN_TYPE, DATA_COMPOSITION_TYPE_FILE, -1);
 #else
       gtk_tree_store_set (GTK_TREE_STORE (model), iter,
                           DATA_COMPOSITION_COLUMN_ICON, icon_file,
                           DATA_COMPOSITION_COLUMN_CONTENT, name,
                           DATA_COMPOSITION_COLUMN_HUMANSIZE, humansize,
-                          DATA_COMPOSITION_COLUMN_SIZE, (guint64) s.st_size, DATA_COMPOSITION_COLUMN_PATH, path,
+                          DATA_COMPOSITION_COLUMN_SIZE, (guint64) s.st_size,
+                          DATA_COMPOSITION_COLUMN_PATH, path,
                           DATA_COMPOSITION_COLUMN_TYPE, DATA_COMPOSITION_TYPE_FILE, -1);
 #endif
 
-      xfburn_data_disc_usage_add_size (XFBURN_DATA_DISC_USAGE (priv->disc_usage), s.st_size);
+      xfburn_disc_usage_add_size (XFBURN_DISC_USAGE (priv->disc_usage), s.st_size);
 #ifdef HAVE_THUNAR_VFS
       if (G_LIKELY (G_IS_OBJECT (mime_icon)))
         g_object_unref (mime_icon);
@@ -1384,7 +1400,7 @@ copy_entry_to (XfburnDataComposition *dc, GtkTreeIter *src, GtkTreeIter *dest, G
       }
     
       if (file_exists_on_same_level (model, path_level, FALSE, name)) {
-        xfce_warn (_("A file named \"%s\" already exists in this directory, the file hasn't been added"), name);
+        xfce_warn (_("A file named \"%s\" already exists in this directory, the file hasn't been added."), name);
         goto cleanup;
       }
       
@@ -1560,7 +1576,7 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
         
           gtk_tree_store_remove (GTK_TREE_STORE (model), &iter_src);
         } else {
-          xfburn_data_disc_usage_add_size (XFBURN_DATA_DISC_USAGE (priv->disc_usage), size);
+          xfburn_disc_usage_add_size (XFBURN_DISC_USAGE (priv->disc_usage), size);
         }
         
         gtk_tree_path_free (path_parent);
@@ -1602,12 +1618,13 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
         full_path[strlen (full_path) - 1] = '\0';
 
       /* remember path to add it later in another thread */
-      priv->full_paths_to_add = g_slist_append (priv->full_paths_to_add, full_path);
+      priv->full_paths_to_add = g_list_append (priv->full_paths_to_add, full_path);
 
       file = strtok (NULL, "\n");
     }
 
-    priv->full_paths_to_add = g_slist_reverse (priv->full_paths_to_add);
+    priv->full_paths_to_add = g_list_reverse (priv->full_paths_to_add);
+    priv->path_where_insert = path_where_insert;
 
     params = g_new (ThreadAddFilesDragParams, 1);
     params->composition = composition;
@@ -1621,7 +1638,59 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
     g_thread_create ((GThreadFunc) thread_add_files_drag, params, FALSE, NULL);
 
     gtk_drag_finish (dc, TRUE, FALSE, t);
-  } else {
+  } 
+  else if (sd->target == gdk_atom_intern ("text/uri-list", FALSE)) {
+#ifdef HAVE_THUNAR_VFS
+    GList *vfs_paths = NULL;
+    GList *vfs_path;
+    GError *error = NULL;
+    gchar *full_path;
+
+    vfs_paths = thunar_vfs_path_list_from_string ((gchar *) sd->data, &error);
+
+    if (G_LIKELY (vfs_paths != NULL)) {
+      ThreadAddFilesDragParams *params;
+      priv->full_paths_to_add = NULL;
+      for (vfs_path = vfs_paths; vfs_path != NULL; vfs_path = g_list_next (vfs_path)) {
+        ThunarVfsPath *path = THUNAR_VFS_PATH (vfs_path->data);
+        if (thunar_vfs_path_get_scheme (path) != THUNAR_VFS_PATH_SCHEME_FILE)
+          continue;
+        full_path = thunar_vfs_path_dup_string (path);
+        g_debug ("adding uri path: %s", full_path);
+        priv->full_paths_to_add = g_list_prepend (priv->full_paths_to_add, full_path);
+      }
+      thunar_vfs_path_list_free (vfs_paths);
+
+      priv->full_paths_to_add = g_list_reverse (priv->full_paths_to_add);
+      priv->path_where_insert = path_where_insert;
+
+      params = g_new (ThreadAddFilesDragParams, 1);
+      params->composition = composition;
+      params->position = position;
+      params->widget = widget;
+
+      /* append a dummy row so that gtk doesn't freak out */
+      gtk_tree_store_append (GTK_TREE_STORE (model), &params->iter_dummy, NULL);
+
+      priv->thread_params = params;
+      g_thread_create ((GThreadFunc) thread_add_files_drag, params, FALSE, NULL);
+
+      gtk_drag_finish (dc, TRUE, FALSE, t);
+    } else {
+      if (G_UNLIKELY (error != NULL))
+        g_warning ("text/uri-list drag failed because '%s'", error->message);
+      else
+        g_warning("There were no files in the uri list!");
+      gtk_drag_finish (dc, FALSE, FALSE, t);
+      xfburn_default_cursor (priv->content);
+    }
+#else
+    g_warning ("Receiving this type of drag and drop requires thunar-vfs support, sorry!");
+    gtk_drag_finish (dc, FALSE, FALSE, t);
+    xfburn_default_cursor (priv->content);
+#endif
+  } 
+  else {
     g_warning ("Trying to receive an unsupported drag target, this should not happen.");
     gtk_drag_finish (dc, FALSE, FALSE, t);
     xfburn_default_cursor (priv->content);
@@ -1640,7 +1709,7 @@ thread_add_files_drag (ThreadAddFilesDragParams *params)
 
   GtkTreeModel *model;
   GtkTreeIter iter_where_insert;
-  GSList *files = priv->full_paths_to_add;
+  GList *files = priv->full_paths_to_add;
 
   gdk_threads_enter ();
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (widget));
@@ -1649,7 +1718,7 @@ thread_add_files_drag (ThreadAddFilesDragParams *params)
   gtk_tree_store_remove (GTK_TREE_STORE (model), &params->iter_dummy);
   gdk_threads_leave ();
 
-  for (; files; files = g_slist_next (files)) {
+  for (; files; files = g_list_next (files)) {
     gchar *full_path = (gchar *) files->data;
     GtkTreeIter iter;
 
@@ -1687,10 +1756,19 @@ fill_image_with_composition (GtkTreeModel *model, IsoImage *image, IsoDir * pare
       gtk_tree_model_get (model, iter, DATA_COMPOSITION_COLUMN_TYPE, &type,
 			  DATA_COMPOSITION_COLUMN_CONTENT, &name, DATA_COMPOSITION_COLUMN_PATH, &src, -1);
 
-      if (type == DATA_COMPOSITION_TYPE_DIRECTORY)
+      if (type == DATA_COMPOSITION_TYPE_DIRECTORY && src == NULL) {
+        /* a directory which the user added for this composition */
         r = iso_tree_add_new_dir (parent, name, &dir);
-      else
+        node = (IsoNode *) dir;
+
+        /* if the new directory is part of the root of the iso,
+         * then its owner will be set to root:root. Not sure what a better
+         * default could be, so I'll just leave it like that. */
+      } else {
+        /* something existing on the filesystem, creating a node
+         * will copy its attributes */
         r = iso_tree_add_node (image, parent, src, &node);
+      }
 
       if (r < 0) {
         if (r == ISO_NULL_POINTER)
@@ -1703,20 +1781,16 @@ fill_image_with_composition (GtkTreeModel *model, IsoImage *image, IsoDir * pare
           g_error ("Failed adding %s as a node to the image: code %d!", src, r);
       }
 
-      /* FIXME: do we need to call iso_node_ref on node? Probably not... */
-      if (type != DATA_COMPOSITION_TYPE_DIRECTORY)
-        iso_node_set_name (node, name);
-
       g_free (name);
       g_free (src);
 
       if (type == DATA_COMPOSITION_TYPE_DIRECTORY && gtk_tree_model_iter_has_child (model, iter)) {
 	GtkTreeIter child;
 
-        /* FIXME: this should not cause a sigfault... 
         if (iso_node_get_type(node) != LIBISO_DIR)
             g_error ("Expected %s to be a directory, but it isn't...\n", src);
-        */
+
+        dir = (IsoDir *)node;
 
 	gtk_tree_model_iter_children (model, &child, iter);
 	fill_image_with_composition (model, image, dir, &child);
@@ -1963,7 +2037,7 @@ save_to_file (XfburnComposition * composition)
   XfburnDataCompositionPrivate *priv = XFBURN_DATA_COMPOSITION_GET_PRIVATE (composition);
   FILE *file_content;
   GtkTreeModel *model;
-  CompositionSaveInfo info = {};
+  CompositionSaveInfo info;
   gint i;
     
   if (!(priv->filename)) {
