@@ -1,4 +1,4 @@
-/* $Id: xfburn-directory-browser.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-directory-browser.c 5403 2008-09-14 08:32:03Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -76,7 +76,8 @@ xfburn_directory_browser_get_type (void)
       NULL,
       sizeof (XfburnDirectoryBrowser),
       0,
-      (GInstanceInitFunc) xfburn_directory_browser_init
+      (GInstanceInitFunc) xfburn_directory_browser_init,
+      NULL
     };
 
     directory_browser_type =
