@@ -1,4 +1,4 @@
-/* $Id: xfburn-file-browser.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-file-browser.c 6059 2008-11-11 03:26:19Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -32,6 +32,7 @@
 #include "xfburn-file-browser.h"
 #include "xfburn-fs-browser.h"
 #include "xfburn-directory-browser.h"
+#include "xfburn-main.h"
 
 #define XFBURN_FILE_BROWSER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_FILE_BROWSER, XfburnFileBrowserPrivate))
 
@@ -73,7 +74,8 @@ xfburn_file_browser_get_type (void)
       NULL,
       sizeof (XfburnFileBrowser),
       0,
-      (GInstanceInitFunc) xfburn_file_browser_init
+      (GInstanceInitFunc) xfburn_file_browser_init,
+      NULL
     };
 
     file_browser_type = g_type_register_static (GTK_TYPE_HPANED, "XfburnFileBrowser", &file_browser_info, 0);
