@@ -1,4 +1,4 @@
-/* $Id: xfburn-main-window.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-main-window.c 6124 2008-11-16 19:34:11Z pollux $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -33,13 +33,14 @@
 #include "xfburn-file-browser.h"
 #include "xfburn-compositions-notebook.h"
 #include "xfburn-blank-dialog.h"
-#include "xfburn-format-dvd-dialog.h"
 #include "xfburn-copy-cd-dialog.h"
 #include "xfburn-copy-dvd-dialog.h"
 #include "xfburn-burn-image-dialog.h"
+#include "xfburn-audio-composition.h"
 #include "xfburn-progress-dialog.h"
 #include "xfburn-settings.h"
 #include "xfburn-main.h"
+#include "xfburn-stock.h"
 
 #define XFBURN_MAIN_WINDOW_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_MAIN_WINDOW, XfburnMainWindowPrivate))
 
@@ -58,7 +59,6 @@ typedef struct {
 
   gboolean support_cdr;
   gboolean support_cdrw;
-  XfburnWelcomeTab *welcome_tab;
 } XfburnMainWindowPrivate;
 
 /* prototypes */
@@ -73,7 +73,7 @@ static void action_about (GtkAction *, XfburnMainWindow *);
 static void action_preferences (GtkAction *, XfburnMainWindow *);
 
 static void action_new_data_composition (GtkAction *, XfburnMainWindow *);
-//static void action_new_audio_composition (GtkAction *, XfburnMainWindow *);
+static void action_new_audio_composition (GtkAction *, XfburnMainWindow *);
 
 /*
 static void action_load (GtkAction *, XfburnMainWindow *);
@@ -87,8 +87,7 @@ static void action_blank (GtkAction *, XfburnMainWindow *);
 static void action_copy_cd (GtkAction *, XfburnMainWindow *);
 static void action_burn_image (GtkAction *, XfburnMainWindow *);
 
-static void action_format_dvd (GtkAction *, XfburnMainWindow *);
-static void action_copy_dvd (GtkAction *, XfburnMainWindow *);
+//static void action_copy_dvd (GtkAction *, XfburnMainWindow *);
 static void action_burn_dvd_image (GtkAction *, XfburnMainWindow *);
 
 static void action_refresh_directorybrowser (GtkAction *, XfburnMainWindow *);
@@ -98,14 +97,14 @@ static void action_show_toolbar (GtkToggleAction * action, XfburnMainWindow * wi
 /* globals */
 static GtkWindowClass *parent_class = NULL;
 static const GtkActionEntry action_entries[] = {
-  {"file-menu", NULL, N_("_File"), NULL,},
+  {"file-menu", NULL, N_("_File"), NULL, NULL, NULL},
   /*{"new-composition", GTK_STOCK_NEW, N_("_New composition"), "", N_("Create a new composition"),},*/
-  {"new-composition", GTK_STOCK_NEW, N_("_New composition"), NULL, N_("Create a new composition"), 
+  /*{"new-composition", GTK_STOCK_NEW, N_("_New composition"), NULL, N_("Create a new composition"), 
+    G_CALLBACK (action_new_data_composition),}, */
+  {"new-data-composition", XFBURN_STOCK_NEW_DATA_COMPOSITION, N_("New data composition"), "<Control><Alt>e", N_("New data composition"),
     G_CALLBACK (action_new_data_composition),},
-  /*{"new-data-composition", GTK_STOCK_HARDDISK, N_("New data composition"), "<Control><Alt>e", N_("New data composition"),
-    G_CALLBACK (action_new_data_composition),},
-  {"new-audio-composition", "audio-x-generic", N_("New audio composition"), "<Control><Alt>A", N_("New audio composition"),
-    G_CALLBACK (action_new_audio_composition),},*/
+  {"new-audio-composition", XFBURN_STOCK_AUDIO_CD, N_("New audio composition"), "<Control><Alt>A", N_("New audio composition"),
+    G_CALLBACK (action_new_audio_composition),},
   /*{"load-composition", GTK_STOCK_OPEN, N_("Load composition"), NULL, N_("Load composition"),
    G_CALLBACK (action_load),},
   {"save-composition", GTK_STOCK_SAVE, N_("Save composition"), NULL, N_("Save composition"), 
@@ -115,27 +114,25 @@ static const GtkActionEntry action_entries[] = {
   {"close-composition", GTK_STOCK_CLOSE, N_("Close composition"), NULL, N_("Close composition"), 
    G_CALLBACK (action_close),},
   {"quit", GTK_STOCK_QUIT, N_("_Quit"), NULL, N_("Quit Xfburn"), G_CALLBACK (action_quit),},
-  {"edit-menu", NULL, N_("_Edit"), NULL,},
+  {"edit-menu", NULL, N_("_Edit"), NULL, NULL, NULL},
   {"preferences", GTK_STOCK_PREFERENCES, N_("Prefere_nces"), NULL, N_("Show preferences dialog"),
    G_CALLBACK (action_preferences),},
-  {"action-menu", NULL, N_("_Actions"), NULL,},
-  {"view-menu", NULL, N_("_View"), NULL,},
+  {"action-menu", NULL, N_("_Actions"), NULL, NULL, NULL},
+  {"view-menu", NULL, N_("_View"), NULL, NULL, NULL},
   {"refresh", GTK_STOCK_REFRESH, N_("Refresh"), NULL, N_("Refresh file list"),
    G_CALLBACK (action_refresh_directorybrowser),},
-  {"help-menu", NULL, N_("_Help"), NULL,},
+  {"help-menu", NULL, N_("_Help"), NULL, NULL, NULL},
   {"about", GTK_STOCK_ABOUT, N_("_About"), NULL, N_("Display information about Xfburn"),
    G_CALLBACK (action_about),},
   {"blank-disc", "xfburn-blank-cdrw", N_("Blank CD-RW"), NULL, N_("Blank CD-RW"),
    G_CALLBACK (action_blank),},
   {"copy-data", "xfburn-data-copy", N_("Copy Data CD"), NULL, N_("Copy Data CD"),
    G_CALLBACK (action_copy_cd),},
-  {"copy-audio", "xfburn-audio-copy", N_("Copy Audio CD"), NULL, N_("Copy Audio CD"),},
+  /*{"copy-audio", "xfburn-audio-copy", N_("Copy Audio CD"), NULL, N_("Copy Audio CD"),}, */
   {"burn-image", "xfburn-burn-cd", N_("Burn Image"), NULL, N_("Burn Image"),
    G_CALLBACK (action_burn_image),},
-  {"format-dvd", "xfburn-format-dvdrw", N_("Format DVD+RW"), NULL, N_("Format DVD+RW"),
-   G_CALLBACK (action_format_dvd),},
-  {"copy-dvd", "xfburn-data-copy", N_("Copy DVD"), NULL, N_("Copy DVD"),
-   G_CALLBACK (action_copy_dvd),},
+/*  {"copy-dvd", "xfburn-data-copy", N_("Copy DVD"), NULL, N_("Copy DVD"),
+   G_CALLBACK (action_copy_dvd),}, */
   {"burn-dvd", "xfburn-burn-image", N_("Burn DVD Image"), NULL, N_("Burn DVD Image"),
    G_CALLBACK (action_burn_dvd_image),},
 };
@@ -148,7 +145,8 @@ static const GtkToggleActionEntry toggle_action_entries[] = {
 };
 
 static const gchar *toolbar_actions[] = {
-  "new-composition",
+  "new-data-composition",
+  "new-audio-composition",
 /*  "load-composition",
   "save-composition",
   "close-composition",*/
@@ -156,7 +154,6 @@ static const gchar *toolbar_actions[] = {
   "copy-data",
   //"copy-audio",
   "burn-image",
-  "format-dvd",
   "copy-dvd",
   "burn-dvd",
   "refresh",
@@ -184,7 +181,8 @@ xfburn_main_window_get_type (void)
       NULL,
       sizeof (XfburnMainWindow),
       0,
-      (GInstanceInitFunc) xfburn_main_window_init
+      (GInstanceInitFunc) xfburn_main_window_init,
+      NULL
     };
 
     main_window_type = g_type_register_static (GTK_TYPE_WINDOW, "XfburnMainWindow", &main_window_info, 0);
@@ -316,7 +314,6 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
   priv->compositions_notebook = xfburn_compositions_notebook_new ();
   gtk_widget_show (priv->compositions_notebook);
   gtk_paned_add2 (GTK_PANED (priv->vpaned), priv->compositions_notebook);
-  priv->welcome_tab = xfburn_compositions_notebook_add_welcome_tab (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook), mainwin);
   
   gtk_paned_set_position (GTK_PANED (priv->vpaned), xfburn_settings_get_int ("vpaned-position", 200));
 
@@ -407,17 +404,7 @@ action_burn_image (GtkAction * action, XfburnMainWindow * window)
   gtk_widget_destroy (dialog);
 }
 
-static void
-action_format_dvd (GtkAction * action, XfburnMainWindow * window)
-{
-  GtkWidget *dialog;
-  
-  dialog = xfburn_format_dvd_dialog_new ();
-  gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
-  gtk_dialog_run (GTK_DIALOG (dialog));
-  gtk_widget_destroy (dialog);
-}
-
+/*
 static void
 action_copy_dvd (GtkAction * action, XfburnMainWindow * window)
 {
@@ -428,6 +415,7 @@ action_copy_dvd (GtkAction * action, XfburnMainWindow * window)
   gtk_dialog_run (GTK_DIALOG (dialog)); 
   gtk_widget_destroy (dialog);
 }
+*/
 
 static void
 action_burn_dvd_image (GtkAction * action, XfburnMainWindow * window)
@@ -473,14 +461,13 @@ action_new_data_composition (GtkAction *action, XfburnMainWindow * window)
   xfburn_main_window_add_data_composition_with_files (window, 0, NULL);
 }
 
-/*
 static void
 action_new_audio_composition (GtkAction *action, XfburnMainWindow * window)
 {
-  XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
+  //XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
  
+  xfburn_main_window_add_audio_composition_with_files (window, 0, NULL);
 }
-*/
 
 static void
 action_quit (GtkAction * action, XfburnMainWindow * window)
@@ -511,6 +498,7 @@ action_about (GtkAction * action, XfburnMainWindow * window)
     {"Stavros Giannouris", "stavrosg2002@freemail.gr", "el",},
     {"Jeff Bailes", "thepizzaking@gmail.com", "en_GB",},
     {"Diego Rodriguez", "dieymir@yahoo.es", "es",},
+    {"Kristjan Siimson", "kristjan.siimson@gmail.com", "et",},
     {"Piarres Beobide", "pi@beobide.net", "eu",},
     {"Jari Rahkonen", "jari.rahkonen@pp1.inet.fi", "fi",},
     {"Etienne Collet", "xanaxlnx@gmail.com", "fr",},
@@ -531,7 +519,7 @@ action_about (GtkAction * action, XfburnMainWindow * window)
     {"Maxim V. Dziumanenko", "mvd@mylinux.com.ua", "uk",},
     {"Dmitry Nikitin", "", "uk",},
     {"ﻢﺤﻣﺩ ﻊﻠﻳ ﺎﻠﻤﻜﻳ", "makki.ma@gmail.com", "ur",},
-    {"正龙 赵", "zzl6612@yahoo.com.cn", "zh_CN",},
+    {"正龙 赵", "longer.zhao@gmail.com", "zh_CN",},
     {"Cosmo Chene", "cosmolax@gmail.com", "zh_TW",},
   };
 
@@ -543,11 +531,11 @@ action_about (GtkAction * action, XfburnMainWindow * window)
     icon = xfce_themed_icon_load (GTK_STOCK_CDROM, x);
 
   info = xfce_about_info_new ("Xfburn", VERSION, _("Another cd burning GUI"),
-                              XFCE_COPYRIGHT_TEXT ("2005-2008", "Jean-François Wauthy, Mario Đanić, David Mohr"), XFCE_LICENSE_GPL);
+                              XFCE_COPYRIGHT_TEXT ("2005-2008", "David Mohr, Mario Đanić, Jean-François Wauthy"), XFCE_LICENSE_GPL);
   xfce_about_info_set_homepage (info, "http://www.xfce.org/projects/xfburn");
-  xfce_about_info_add_credit (info, "Jean-François Wauthy", "pollux@xfce.org", _("Author/Maintainer"));
-  xfce_about_info_add_credit (info, "Mario Đanić", "mario@libburnia-project.org", _("Author/Maintainer"));
   xfce_about_info_add_credit (info, "David Mohr", "david@mcbf.net", _("Author/Maintainer"));
+  xfce_about_info_add_credit (info, "Mario Đanić", "mario@libburnia-project.org", _("Author/Maintainer"));
+  xfce_about_info_add_credit (info, "Jean-François Wauthy", "pollux@xfce.org", _("Retired author/maintainer"));
   
 
   for (n = 0; n < G_N_ELEMENTS (translators); ++n) {
@@ -677,7 +665,8 @@ xfburn_main_window_new (void)
       gtk_action_set_sensitive (action, FALSE);
     }
 
-    g_object_set (priv->welcome_tab, "action_group", priv->action_group, NULL);
+    /* show welcome tab */
+    xfburn_compositions_notebook_add_welcome_tab (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook), priv->action_group);
   }
 
   return obj;
@@ -718,6 +707,16 @@ xfburn_main_window_add_data_composition_with_files (XfburnMainWindow *window, in
   xfburn_data_composition_add_files (XFBURN_DATA_COMPOSITION (comp), filec, filenames);
 }
 
+void 
+xfburn_main_window_add_audio_composition_with_files (XfburnMainWindow *window, int filec, char **filenames)
+{
+  XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
+  XfburnComposition *comp;
+ 
+  comp = xfburn_compositions_notebook_add_composition (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook), XFBURN_AUDIO_COMPOSITION);
+  xfburn_audio_composition_add_files (XFBURN_AUDIO_COMPOSITION (comp), filec, filenames);
+}
+
 gboolean
 xfburn_main_window_support_cdr (XfburnMainWindow *window)
 {
