@@ -32,6 +32,8 @@
 
 #include "xfburn-device-box.h"
 
-void xfburn_perform_burn_write (GtkWidget *dialog_progress, struct burn_drive *drive, XfburnWriteMode write_mode, struct burn_write_opts *burn_options, struct burn_disc *disc, struct burn_source *fifo);
+void xfburn_perform_burn_write (GtkWidget *dialog_progress, 
+                                struct burn_drive *drive, XfburnWriteMode write_mode, struct burn_write_opts *burn_options, int sector_size,
+                                struct burn_disc *disc, struct burn_source **fifos, int *track_sectors);
 
 #endif /* __XFBURN_PERFORM_BURN_H__ */
