@@ -1,4 +1,4 @@
-/* $Id: xfburn-preferences-dialog.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-preferences-dialog.c 6779 2009-02-25 02:12:30Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -29,6 +29,8 @@
 #include "xfburn-utils.h"
 #include "xfburn-settings.h"
 
+#define FIFO_MAX_SIZE     16384.0  /* in kb, as float */
+
 #define XFBURN_PREFERENCES_DIALOG_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_PREFERENCES_DIALOG, XfburnPreferencesDialogPrivate))
 
 typedef struct
@@ -100,6 +102,7 @@ xfburn_preferences_dialog_get_type ()
       sizeof (XfburnPreferencesDialog),
       0,
       (GInstanceInitFunc) xfburn_preferences_dialog_init,
+      NULL
     };
 
     type = g_type_register_static (XFCE_TYPE_TITLED_DIALOG, "XfburnPreferencesDialog", &our_info, 0);
@@ -137,6 +140,7 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   
   gtk_window_set_title (GTK_WINDOW (obj), _("Preferences"));
   xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (obj), _("Tune how Xfburn behaves"));
+  gtk_window_set_default_size (GTK_WINDOW (obj), 775, 400);
   gtk_window_set_destroy_with_parent (GTK_WINDOW (obj), TRUE);
   gtk_window_set_icon_name (GTK_WINDOW (obj), GTK_STOCK_PREFERENCES);
   gtk_dialog_set_has_separator (GTK_DIALOG (obj), FALSE);
@@ -313,7 +317,7 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
 
 
   /* below the device list */
-  priv->check_empty_speed_list = gtk_check_button_new_with_mnemonic (_("Show _empty speed list bug warning"));
+  priv->check_empty_speed_list = gtk_check_button_new_with_mnemonic (_("Show warning on _empty speed list"));
   gtk_box_pack_start (GTK_BOX (vbox2), priv->check_empty_speed_list, FALSE, FALSE, BORDER);
   gtk_widget_show (priv->check_empty_speed_list);
 
@@ -325,7 +329,7 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, BORDER);
   gtk_widget_show (frame);
 
-  priv->scale_fifo = gtk_hscale_new_with_range (0.0, 8192.0, 32.0);
+  priv->scale_fifo = gtk_hscale_new_with_range (0.0, FIFO_MAX_SIZE, 32.0);
   gtk_scale_set_value_pos (GTK_SCALE (priv->scale_fifo), GTK_POS_LEFT);
   gtk_range_set_value (GTK_RANGE (priv->scale_fifo), 0);
   gtk_box_pack_start (GTK_BOX (vbox3), priv->scale_fifo, FALSE, FALSE, BORDER/2);
@@ -368,7 +372,7 @@ xfburn_preferences_dialog_load_settings (XfburnPreferencesDialog * dialog)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->check_empty_speed_list),
                                 xfburn_settings_get_boolean ("show-empty-speed-list-notice", TRUE));
   gtk_range_set_value (GTK_RANGE (priv->scale_fifo),
-                                (double) xfburn_settings_get_int ("fifo-size", XFBURN_FIFO_DEFAULT_SIZE));
+                                (double) xfburn_settings_get_int ("fifo-size", FIFO_DEFAULT_SIZE));
 }
 
 static void
@@ -414,7 +418,7 @@ refresh_devices_list (XfburnPreferencesDialog * dialog)
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
     gtk_list_store_set (GTK_LIST_STORE (model), &iter,
                         DEVICE_LIST_COLUMN_NAME, device_data->name,
-                        DEVICE_LIST_COLUMN_NODE, device_data->node_path,
+                        DEVICE_LIST_COLUMN_NODE, device_data->addr,
                         DEVICE_LIST_COLUMN_CDR, device_data->cdr,
                         DEVICE_LIST_COLUMN_CDRW, device_data->cdrw,
                         DEVICE_LIST_COLUMN_DVDR, device_data->dvdr, DEVICE_LIST_COLUMN_DVDRAM, device_data->dvdram, -1);
